[−][src]Struct arc_swap::Lease
A temporary storage of the pointer.
This, unlike Guard, does not block any write operations and is usually
faster than loading the full Arc. However, this holds only if each thread keeps only small
number of Leases around and if too many are held, the following ones will just fall back to
creating the Arc internally.
Methods
impl<T: RefCnt> Lease<T>[src]
pub fn upgrade(lease: &Self) -> T[src]
Loads a full Arc from the lease.
pub fn into_upgrade(lease: Self) -> T[src]
A consuming version of upgrade.
This is a bit faster in certain situations, but consumes the lease.
pub fn get_ref(lease: &Self) -> Option<&T::Base>[src]
Returns access to the data held.
This returns Option even when it can't hold NULL internally, to keep the interface the
same. But there's also the Deref trait for the non-NULL cases, which is usually more
comfortable.
pub fn is_null(lease: &Self) -> bool[src]
Checks if it contains a null pointer.
Note that for non-NULL T, this always returns false.
impl<T: NonNull> Lease<Option<T>>[src]
pub fn expect(self, msg: &str) -> Lease<T>[src]
Like [unwrap][Lease::unwrap], but with a panic message.
Panics
If the lease contains a NULL pointer.
pub fn unwrap(self) -> Lease<T>[src]
Asserts the lease contains non-NULL content and gets direct access to it.
This is very much like [Option::unwrap].
Panics
If the lease contains a NULL pointer.
pub fn into_option(self) -> Option<Lease<T>>[src]
Transposes the Lease<Option<RefCnt>> into Option<Lease<RefCnt>>.
Examples
let shared = ArcSwapOption::from_pointee(42); if let Some(ptr) = shared.lease().into_option() { println!("It is {}", ptr); } else { println!("Nothing present"); }